@@ -343,7 +343,7 @@ class BaseServer(object):
         query_string = urllib.urlencode(parameters)
         url = 'http://%s:%s/function/schedulerserver/remoteremovefromheap?%s' % (self.scheduler_server, self.schedulerserver_port, query_string)
         deferreds = []
-        deferreds.append(self.getPage(url=url))
+        # deferreds.append(self.getPage(url=url))
         deferreds.append(self.s3.deleteObject(self.aws_s3_storage_bucket, uuid))
         d = DeferredList(deferreds)
         d.addCallback(self._deleteReservationCallback, function_name, uuid)
